package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.AmstruckInwardRequirementMapper;
import com.steerinfo.dil.model.AmstruckInwardRequirement;
import com.steerinfo.dil.service.IAmstruckInwardRequirementService;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.framework.mapper.IBaseMapper;
import com.steerinfo.framework.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * AmstruckInwardRequirement服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-25 11:30
 * 类描述
 * 修订历史：
 * 日期：2021-10-25
 * 作者：generator
 * 参考：
 * 描述：AmstruckInwardRequirement服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "amstruckInwardRequirementService")
public class AmstruckInwardRequirementServiceImpl extends BaseServiceImpl<AmstruckInwardRequirement, BigDecimal> implements IAmstruckInwardRequirementService {

    @Autowired
    private AmstruckInwardRequirementMapper amstruckInwardRequirementMapper;

    @Override
    protected IBaseMapper<AmstruckInwardRequirement, BigDecimal> getMapper() {
        return amstruckInwardRequirementMapper;
    }


    @Override
    public int insert(AmstruckInwardRequirement amstruckInwardRequirement) {
        //设置主键
        amstruckInwardRequirement.setRequirementId(amstruckInwardRequirementMapper.selectOtherId());
        DataChange dataChange=new DataChange();
        amstruckInwardRequirement.setRequirementNumber(dataChange.generateEightDigitsNumber("YSXQ",amstruckInwardRequirementMapper.selectOtherId().intValue()));
        amstruckInwardRequirement.setRequirementStatus(new BigDecimal(0));
        // 设置常规字段
        amstruckInwardRequirement.setInsertTime(new Date());
        amstruckInwardRequirement.setInsertUsername("admin");
        amstruckInwardRequirement.setInsertUpdateRemark("无");
        amstruckInwardRequirement.setDeleted(new BigDecimal(0));
        return amstruckInwardRequirementMapper.insertSelective(amstruckInwardRequirement);
    }

    /**
     * 查询用车需求
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getTruckRequirementList(Map<String, Object> mapValue) {
        List<Map<String, Object>> mapList;
        if (((Integer) mapValue.get("requirementStatus")) == 2) {
            mapList = amstruckInwardRequirementMapper.getFinishTruckRequirementList(mapValue);
        }
        else {
            mapList = amstruckInwardRequirementMapper.getTruckRequirementList(mapValue);
        }

        return mapList;
    }

    /**
     * 删除用车需求
     * @param requirementId
     * @return
     */
    @Override
    public int deleteTruckRequirement(BigDecimal requirementId) {
        AmstruckInwardRequirement amstruckInwardRequirement = amstruckInwardRequirementMapper.selectByPrimaryKey(requirementId);
        amstruckInwardRequirement.setDeleted(new BigDecimal(1));
        int result = amstruckInwardRequirementMapper.updateByPrimaryKeySelective(amstruckInwardRequirement);
        return result;
    }

    /**
     * 修改用车需求
     * @param amstruckInwardRequirement
     * @return
     */
    @Override
    public int updateTruckRequirement(AmstruckInwardRequirement amstruckInwardRequirement) {
        int result = amstruckInwardRequirementMapper.updateByPrimaryKeySelective(amstruckInwardRequirement);
        return result;
    }

    /**
     * 查询修改渲染
     * @param requirementId
     * @return
     */
    @Override
    public List<Map<String, Object>> selectRequirement(Integer requirementId) {
        return amstruckInwardRequirementMapper.selectRequirement(new BigDecimal(requirementId));
    }

    /**
     * 下发需求
     * @param requirementIds
     * @return
     */
    @Override
    public int downRequirement(List<Map<String,Object>> requirementIds) {
        int result = 0;
        for (Map<String,Object> map : requirementIds) {
            Integer requirementId = (Integer) map.get("requirementId");
            AmstruckInwardRequirement amstruckInwardRequirement = amstruckInwardRequirementMapper.selectByPrimaryKey(new BigDecimal(requirementId));
            amstruckInwardRequirement.setRequirementStatus(new BigDecimal(1));
            result += amstruckInwardRequirementMapper.updateByPrimaryKeySelective(amstruckInwardRequirement);
        }
        return result;
    }

    /**
     * 接收需求
     * @param requirementId
     * @return
     */
    @Override
    public int receiveRequirement(Integer requirementId) {
        AmstruckInwardRequirement amstruckInwardRequirement = amstruckInwardRequirementMapper.selectByPrimaryKey(new BigDecimal(requirementId));
        amstruckInwardRequirement.setRequirementStatus(new BigDecimal(2));
        amstruckInwardRequirement.setUpdateTime(new Date());
        amstruckInwardRequirement.setUpdateUsername("admin");
        int result = amstruckInwardRequirementMapper.updateByPrimaryKeySelective(amstruckInwardRequirement);
        return result;
    }

    /**
     * 批次信息
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getPurchaseIdByBatch(Map<String, Object> mapValue) {
        List<Map<String, Object>> mapList = amstruckInwardRequirementMapper.getPurchaseIdByBatch(mapValue);
//        for (Map<String,Object> map : mapList) {
//            BigDecimal purchaseOrderId = (BigDecimal) map.get("purchaseOrderId");
//            Map<String,Object> purchaseMap = new HashMap<>();
//            purchaseMap.put("purchaseOrderId",purchaseOrderId);
//            List<AmstruckInwardRequirement> amstruckInwardRequirements = amstruckInwardRequirementMapper.selectByParameters(purchaseMap);
//            if (amstruckInwardRequirements.size() == 0 || amstruckInwardRequirements == null) {
//            }
//            else {
//                mapList.remove(map);
//            }
//        }
        return mapList;
    }

    /**
     * 车型下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getCapacityType() {
        return amstruckInwardRequirementMapper.getCapacityType();
    }

    /**
     * 用车单位下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getShipperUser() {
        return amstruckInwardRequirementMapper.getShipperUser();
    }

    /**
     * 查询所有仓库
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getWareHouse(Map<String, Object> mapValue) {
        return amstruckInwardRequirementMapper.getWareHouse(mapValue);
    }
}
